@@ -313,9 +313,6 @@ typedef struct nvGpuRec {
 typedef struct nvLayoutRec {
     XConfigLayoutPtr conf_layout;
     char *filename;
-    Bool  advanced_mode; /* Allow advanced layout modifications: */
-                         /*   - panning */
-                         /*   - multiple (meta)modes */
 
     NvCtrlAttributeHandle *handle;
 
