@@ -23,11 +23,34 @@
  */
  
 #include <gtk/gtk.h>
+#include <NvCtrlAttributes.h>
 #include "ctkutils.h"
 #include "msg.h"
 
 
 
+gchar* create_gpu_name_string(NvCtrlAttributeHandle *gpu_handle)
+{
+    gchar *gpu_name;
+    gchar *gpu_product_name;
+    ReturnStatus ret;
+    
+    ret = NvCtrlGetStringDisplayAttribute(gpu_handle, 0,
+                                          NV_CTRL_STRING_PRODUCT_NAME,
+                                          &gpu_product_name);
+    if (ret == NvCtrlSuccess && gpu_product_name) {
+        gpu_name = g_strdup_printf("GPU %d - (%s)",
+                                   NvCtrlGetTargetId(gpu_handle),
+                                   gpu_product_name);
+    } else {
+        gpu_name = g_strdup_printf("GPU %d - (Unknown)",
+                                   NvCtrlGetTargetId(gpu_handle));
+    }
+    g_free(gpu_product_name);
+    
+    return gpu_name;
+}
+
 
 GtkWidget *add_table_row(GtkWidget *table,
                          const gint row,
@@ -141,3 +164,30 @@ void ctk_display_warning_msg(GtkWidget *parent, gchar * msg)
     }
 
 } /* ctk_display_warning_msg() */
+
+
+
+/** ctk_empty_container() ********************************************
+ *
+ * Removes all (non internal) children widgets from a container
+ *
+ * XXX It might be useful later on to allow a callback to be called
+ *     for each widget that gets removed etc.
+ *
+ **/
+
+void ctk_empty_container(GtkWidget *container)
+{
+    GList *list;
+    GList *node;
+
+    list = gtk_container_get_children(GTK_CONTAINER(container));
+    node = list;
+    while (node) {
+        gtk_container_remove(GTK_CONTAINER(container),
+                             (GtkWidget *)(node->data));
+        node = node->next;
+    }
+    g_list_free(list);
+
+} /* ctk_empty_container() */
