@@ -26,10 +26,12 @@
 #define __CTK_UTILS_H__
 
 #include <gtk/gtk.h>
-
+#include <NvCtrlAttributes.h>
 
 G_BEGIN_DECLS
 
+gchar* create_gpu_name_string(NvCtrlAttributeHandle *gpu_handle);
+
 GtkWidget *add_table_row(GtkWidget *, const gint,
                          const gfloat, const gfloat, const gchar *,
                          const gfloat, const gfloat, const gchar *);
@@ -40,6 +42,8 @@ void ctk_display_error_msg(GtkWidget *parent, gchar *msg);
 
 void ctk_display_warning_msg(GtkWidget *parent, gchar *msg);
 
+void ctk_empty_container(GtkWidget *);
+
 G_END_DECLS
 
 #endif /* __CTK_UTILS_H__ */
