@@ -122,6 +122,10 @@ struct __NvCtrlXvOverlayAttributes {
 struct __NvCtrlXvTextureAttributes {
     unsigned int port;
     NvCtrlXvAttribute *sync_to_vblank;
+    NvCtrlXvAttribute *contrast;
+    NvCtrlXvAttribute *brightness;
+    NvCtrlXvAttribute *hue;
+    NvCtrlXvAttribute *saturation;
     NvCtrlXvAttribute *defaults;
 };
 
@@ -248,7 +252,7 @@ NvCtrlNvControlQueryTargetCount(NvCtrlAttributePrivateHandle *, int, int *);
 
 ReturnStatus
 NvCtrlNvControlGetAttribute (NvCtrlAttributePrivateHandle *, unsigned int,
-                             int, int *);
+                             int, int64_t *);
 
 ReturnStatus
 NvCtrlNvControlSetAttribute (NvCtrlAttributePrivateHandle *, unsigned int,
@@ -262,6 +266,13 @@ ReturnStatus
 NvCtrlNvControlGetValidAttributeValues (NvCtrlAttributePrivateHandle *,
                                         unsigned int, int,
                                         NVCTRLAttributeValidValuesRec *);
+
+ReturnStatus
+NvCtrlNvControlGetValidStringDisplayAttributeValues
+                                      (NvCtrlAttributePrivateHandle *,
+                                       unsigned int, int,
+                                       NVCTRLAttributeValidValuesRec *);
+
 ReturnStatus
 NvCtrlNvControlGetStringAttribute (NvCtrlAttributePrivateHandle *,
                                    unsigned int, int, char **);
